@@ -110,17 +110,11 @@ gpm_prefs_class_init (GpmPrefsClass *klass)
  * Activates (shows) the window.
  **/
 void
-#if GTK_CHECK_VERSION (3, 0, 0)
 gpm_prefs_activate_window (GtkApplication *app, GpmPrefs *prefs)
-#else
-gpm_prefs_activate_window (GpmPrefs *prefs)
-#endif
 {
 	GtkWindow *window;
 	window = GTK_WINDOW (gtk_builder_get_object (prefs->priv->builder, "dialog_preferences"));
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_application_add_window (GTK_APPLICATION (app), window);
-#endif
 	gtk_window_present (window);
 }
 
@@ -871,10 +865,6 @@ gpm_prefs_init (GpmPrefs *prefs)
 	prefs_setup_ups (prefs);
 	prefs_setup_general (prefs);
 	prefs_setup_notification (prefs);
-
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	gtk_widget_show (main_window);
-#endif
 }
 
 /**
